==> haskell-mtl-2.2.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mtl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mtl
version: 2.2.1
id: mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
key: mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
license: BSD3
maintainer: Edward Kmett <ekmett@gmail.com>
homepage: http://github.com/ekmett/mtl
synopsis: Monad classes, using functional dependencies
description:
    Monad classes using functional dependencies, with instances
    for various monad transformers, inspired by the paper
    /Functional Programming with Overloading and Higher-Order Polymorphism/,
    by Mark P Jones, in /Advanced School of Functional Programming/, 1995
    (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).
category: Control
author: Andy Gill
exposed: True
exposed-modules:
    Control.Monad.Cont Control.Monad.Cont.Class Control.Monad.Error
    Control.Monad.Error.Class Control.Monad.Except
    Control.Monad.Identity Control.Monad.List Control.Monad.RWS
    Control.Monad.RWS.Class Control.Monad.RWS.Lazy
    Control.Monad.RWS.Strict Control.Monad.Reader
    Control.Monad.Reader.Class Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict
abi: 3d1c9cc97cc77cce4cb56eb9f10cdcab
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/mtl-2.2.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/mtl-2.2.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/mtl-2.2.1
hs-libraries: HSmtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
depends:
    base-4.9.0.0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-mtl/html/mtl.haddock
haddock-html: /usr/share/doc/haskell-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mtl-2.2.1-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mtl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mtl
version: 2.2.1
id: mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
key: mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
license: BSD3
maintainer: Edward Kmett <ekmett@gmail.com>
homepage: http://github.com/ekmett/mtl
synopsis: Monad classes, using functional dependencies
description:
    Monad classes using functional dependencies, with instances
    for various monad transformers, inspired by the paper
    /Functional Programming with Overloading and Higher-Order Polymorphism/,
    by Mark P Jones, in /Advanced School of Functional Programming/, 1995
    (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).
category: Control
author: Andy Gill
exposed: True
exposed-modules:
    Control.Monad.Cont Control.Monad.Cont.Class Control.Monad.Error
    Control.Monad.Error.Class Control.Monad.Except
    Control.Monad.Identity Control.Monad.List Control.Monad.RWS
    Control.Monad.RWS.Class Control.Monad.RWS.Lazy
    Control.Monad.RWS.Strict Control.Monad.Reader
    Control.Monad.Reader.Class Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict
abi: 1a6c5dba975440616b273bb56f048899
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/mtl-2.2.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/mtl-2.2.1
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/mtl-2.2.1
hs-libraries: HSmtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
depends:
    base-4.9.1.0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-mtl/html/mtl.haddock
haddock-html: /usr/share/doc/haskell-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
